@@ -25,6 +25,7 @@
 
 #include <X11/extensions/XTest.h>
 #include <X11/Xlib.h>
+#include <X11/XKBlib.h>
 #include <X11/keysym.h>
 #include <X11/keysymdef.h>
 
@@ -34,8 +35,8 @@
 #include <math.h>
 #include <tqfont.h>
 #include <tqfontdialog.h>
-#include <kconfig.h>
-#include <kapplication.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
 
 
 
@@ -46,7 +47,7 @@
 
 bool shutting=false;
 
-MainWidget::MainWidget ( KAboutData *about, bool tren, TQWidget *parent, const char * name, WFlags f ) : ResizableDragWidget ( parent,name,f ), stand_alone(tren)
+MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const char * name, WFlags f ) : ResizableDragWidget ( parent,name,f ), stand_alone(tren)
 {
 
 	
@@ -54,7 +55,7 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, TQWidget *parent, const c
 
 	nresize=false;
 	
-	display=qt_xdisplay();
+	display=tqt_xdisplay();
 	
 	//TQString k1= "`1234567890-=";
 	//TQString k1s = "~!@#$%^&*()_+";
@@ -498,9 +499,9 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, TQWidget *parent, const c
 		tray = new KbdTray ( this );
 		tray->setPixmap ( UserIcon ( "tray" ) );
 	
-		KConfig *cfg = KApplication::kApplication()->config();
+		TDEConfig *cfg = TDEApplication::kApplication()->config();
 	
-		KPopupMenu *m = tray->contextMenu();
+		TDEPopupMenu *m = tray->contextMenu();
 		m->setCheckable ( true );
 	
 		KHelpMenu *h = new KHelpMenu ( tray, about );
@@ -559,7 +560,7 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, TQWidget *parent, const c
 
 void MainWidget::finishInit()
 {
-	KConfig *cfg = KApplication::kApplication()->config();
+	TDEConfig *cfg = TDEApplication::kApplication()->config();
 	bool vis = cfg->readBoolEntry("visible",true);
 	if (vis) {
 		show();
@@ -584,8 +585,8 @@ void MainWidget::restorePosition()
 	int d_height=235;
 	TQRect dflt_geom(screen_geom.width()-d_width,screen_geom.height()-d_height,d_width,d_height);
 
-	KConfig *cfg = 0;
-	cfg = KApplication::kApplication()->config();
+	TDEConfig *cfg = 0;
+	cfg = TDEApplication::kApplication()->config();
 	if (cfg){
 		TQRect geom  = cfg->readRectEntry("geometry");
 		if (!geom.isNull() && geom.isValid()) {
@@ -596,8 +597,8 @@ void MainWidget::restorePosition()
 }
 void MainWidget::saveState()
 {
-	KConfig *cfg = 0;
-	cfg = KApplication::kApplication()->config();
+	TDEConfig *cfg = 0;
+	cfg = TDEApplication::kApplication()->config();
 	if (cfg){
 		cfg->writeEntry("visible",isShown());
 		cfg->sync();
@@ -606,8 +607,8 @@ void MainWidget::saveState()
 void MainWidget::hideEvent ( TQHideEvent * )
 {
 	
-	KConfig *cfg = 0;
-	cfg = KApplication::kApplication()->config();
+	TDEConfig *cfg = 0;
+	cfg = TDEApplication::kApplication()->config();
 	if (cfg){
 		cfg->writeEntry("geometry",geometry());
 		cfg->sync();
@@ -662,7 +663,7 @@ void MainWidget::resizeEvent(TQResizeEvent * e)
 void MainWidget::showConfigMenu()
 {
 	if (tray){
-		KPopupMenu *m = tray->contextMenu();
+		TDEPopupMenu *m = tray->contextMenu();
 		m->popup(mapToGlobal(popup_menu->pos()));
 	}
 }
@@ -714,7 +715,7 @@ void MainWidget::chooseFont()
         // value, in this case Helvetica [Cronyx], 10
     }
 	
-	KConfig *cfg = KApplication::kApplication()->config();
+	TDEConfig *cfg = TDEApplication::kApplication()->config();
 	cfg->writeEntry ("KvkbdFont", this->font());
 	cfg->sync();
 	
@@ -739,7 +740,7 @@ void MainWidget::showDock()
 		tray->contextMenu()->setItemChecked ( mnu_dock, !c );
 		dock->show();
 	}
-	KConfig *cfg = KApplication::kApplication()->config();
+	TDEConfig *cfg = TDEApplication::kApplication()->config();
 	cfg->writeEntry ("showdock", !c);
 	cfg->sync();
 	
@@ -748,7 +749,7 @@ void MainWidget::toggleFontAutoRes()
 {
 	bool c = tray->contextMenu()->isItemChecked( mnu_autores);
 	tray->contextMenu()->setItemChecked(mnu_autores, !c);
-	KConfig *cfg = KApplication::kApplication()->config();
+	TDEConfig *cfg = TDEApplication::kApplication()->config();
 	cfg->writeEntry ("autoresfont", !c);
 	cfg->sync();
 }
@@ -876,9 +877,9 @@ void MainWidget::setupText(VButton& v)
 	
 	KeyCode keycode=v.getKeyCode();
 
-	KeySym keysym_l = XKeycodeToKeysym(display, keycode, 0);
+	KeySym keysym_l = XkbKeycodeToKeysym(display, keycode, 0, 0);
 
-	KeySym keysym_u = XKeycodeToKeysym(display, keycode, 1);
+	KeySym keysym_u = XkbKeycodeToKeysym(display, keycode, 0, 1);
 
 	long ret = keysym2ucs(keysym_l);
 
